####Exerccios 5 - Criao de Grficos

###############################################
##5.1 Editando alguns parametros graficos
###############################################
#Carregando o input e armazenando no objeto 'saligna'
saligna <- read.csv("esaligna.csv", header = TRUE, as.is = TRUE)

#Checando o nome das variaveis
colnames(saligna)

#Construindo o grafico
png(filename = "saligna.png") #abrindo um dispositivo grafico para imagem png
par(mar=c(6,10,8,2)) #definindo o tamanho das margens 
par(pch= 16, tcl= 0.3, bty="l") #definindo tipo de ponto, caixa de plotagem e posicao e o tamanho dos tick marks
par(las= 1,  cex.axis= 1.5, cex.main= 1.8) #definindo a posicao dos valores dos eixos, o tamanho da fonte dos eixos e o tamanho do titulo
plot(ht ~ dap, data = saligna, cex= 1.4, 
     col= "red", xlab= "", ylab= "", xlim= c(0,30),
     ylim= c(0,30), main= "Eucalypthus saligna") #Plotando o grafico com titulo e com pontos vermelhos 40% maiores que o padrao
mtext("Dimetro  altura do peito (cm)", side=1, cex= 1.7, line=3.5, family="serif") #adicionando a legenda do eixo x 70% maior que o padrao
mtext("Altura (m)", side=2, cex= 1.7, line=3.5, family="serif") #adicionando a legenda do eixo y 70% maior que o padrao
dev.off() #fechando o dispositivo png para salvar a imagem


###############################################
##5.2 Dois graficos juntos
###############################################
#Checando o nome das variaveis
colnames(saligna)

#Checando a estrutura dos dados
str(saligna)

#Transformando a variavel 'talhao' em fator
saligna$talhao <- factor(saligna$talhao)

#Calculando a media do dap por talhao e armazenando em um vetor
media.tlh <- as.vector(tapply(saligna$dap, saligna$talhao, mean))
names(media.tlh) <- names(tapply(saligna$dap, saligna$talhao, mean))
media.tlh

#Calculando o desvio padrao do dap por talhao e armazenando em um vetor
sd.tlh <- tapply(saligna$dap, saligna$talhao, sd)
names(sd.tlh) <- names(tapply(saligna$dap, saligna$talhao, sd))
sd.tlh

##Construindo os graficos
png(filename = "dois_graficos_juntos.png", width=600, height=340) #abrindo um dispositivo grafico para imagem png
#Definindo os parametros gerais da plotagem
par(mfrow= c(1,2)) #definindo a area de plotagem com uma linha e duas colunas
par(tcl= 0.3, bty="l") #definindo o tipo de caixa de plotagem e posicao e tamanho dos tick marks
par(las= 1,  cex.axis= 1.2) #definindo a posicao dos valores e tamanho da fonte das legendas dos eixos
#Construindo o primeiro grafico (boxplot)
par(mar=c(4,4,1,0.5)) #definindo o tamanho das margens 
boxplot(dap ~ talhao, data = saligna, xlab= "", ylab= "", ylim= c(0,25)) #plotando o boxplot
mtext("Talho", side=1, cex= 1.5, line=2.5, family="serif") #adicionando a legenda do eixo x do boxplot 50% maior que o padrao
text(1,25,"a", cex= 1.5) #adicionando a letra 'a' no canto superior esquerdo
#Adicionando a legenda do eixo y que sera comum a ambos os graficos
corners <- par("usr") #armazenando o valor dos quatro cantos da area de plotagem (x1, x2, y1, y2)
par(xpd = TRUE) #definindo a adicao do texto para fora da area de plotagem
text(x = corners[1]-1.4, y = mean(corners[3:4]), labels = "Dimetro  altura do peito (cm)",
     srt = 90, cex = 1.5) #adicionando a legenda do eixo y 50% maior que o padrao e paralela a este eixo
#Construindo o segundo grafico
par(mar=c(4,2,1,0.5)) #definindo o tamanho das margens
plot(media.tlh, cex= 1.4, col= "red", xlab= "", ylab= "", ylim= c(0,25), pch= 16, xaxt="n") #plotando o segundo grafico sem o eixo x 
mtext("Talho", side= 1, cex= 1.5, line=2.5, family="serif") #adicionando a legenda do eixo x do segundo grafico 50% maior que o padrao
#Adicionando os "whiskers" das barras de desvio padro
points(media.tlh + sd.tlh, pch="-", cex= 1.4)
points(media.tlh - sd.tlh, pch="-", cex= 1.4)
#Adicionando as barras de desvio padro
lines(x= c(1,1), y= c(media.tlh[1]-sd.tlh[1], media.tlh[1]+sd.tlh[1]))
lines(x= c(2,2), y= c(media.tlh[2]-sd.tlh[2], media.tlh[2]+sd.tlh[2]))
lines(x= c(3,3), y= c(media.tlh[3]-sd.tlh[3], media.tlh[3]+sd.tlh[3]))
lines(x= c(4,4), y= c(media.tlh[4]-sd.tlh[4], media.tlh[4]+sd.tlh[4]))
lines(x= c(5,5), y= c(media.tlh[5]-sd.tlh[5], media.tlh[5]+sd.tlh[5]))
lines(x= c(6,6), y= c(media.tlh[6]-sd.tlh[6], media.tlh[6]+sd.tlh[6]))
#Ajustes finais
axis(side= 1, at=1:6, labels= as.numeric(names(media.tlh[1:6]))) #adicionando o mesmo eixo x do boxplot
text(1.4,25,"b", cex= 1.5) #adicionando a letra 'b' no canto superior esquerdo
dev.off() #fechando o dispositivo png para salvar a imagem


###############################################
##5.3 Adivinhando o codigo
###############################################
#Carregando os dados
dados <- read.table("dados.txt", header = TRUE, as.is = TRUE, sep= ",")

#Checando a estrutura das variaveis
str(dados)

#Analisando a amplitude das variaveis
range(dados$x1, na.rm = T)
range(dados$y1, na.rm = T)
range(dados$x2)
range(dados$y2) #conclusao: o primeiro grafico utilizou x1 e y1 enquanto o segundo x2 e y2

##Construindo os graficos
png(filename = "adiv_grafic.png", width=600, height=340) #abrindo um dispositivo grafico para imagem png
#Definindo os parametros gerais da plotagem
par(mfrow= c(1,2)) #definindo a area de plotagem com uma linha e duas colunas
par(tcl= 0.3, bty="l") #definindo o tipo de caixa de plotagem e posicao e tamanho dos tick marks
par(family="serif") #definindo a fonte das legendas e dos valores dos eixos
#Construindo o primeiro grafico
par(mar=c(4,6,2,0.5)) #definindo o tamanho das margens
plot(dados$x1[-23], dados$y1[-23], ylim= c(0,3), xlab= "", ylab= "", pch= 17) #plotando o primeiro grafico com pontos representados por triangulos pretos
mtext("Log(Patch size)(ha)", side= 1, line= 2.2, family="serif") #adicionando a legenda do eixo x do primeiro grafico
text(2.2,3,"a", cex= 1.5)#adicionando a letra 'a' no canto superior direito
#Adicionanso a legenda do eixo y que sera comum a ambos os graficos 
corners <- par("usr") #armazenando o valor dos quatro cantos da area de plotagem (x1, x2, y1, y2)
par(xpd = TRUE) #definindo a adicao do texto para fora da area de plotagem
text(x = corners[1]-0.4, y = mean(corners[3:4]), labels = "Euclidean distances",
     srt = 90, cex= 1.5) #adicionando a legenda do eixo y 50% maior que o padrao e paralela a este eixo
segments(x0= 0.5, y0= 2.25, x1= 2.15, y1= 1, lwd = 2) #plotando a linha de tendencia
#Construindo o segundo grafico (boxplot)
par(mar=c(4,2,2,0)) #definindo o tamanho das margens
boxplot(x2 ~ y2, data = dados, ylab= "", xlab = "", ylim= c(0,3), xaxt="n", outline= FALSE) #plotando o boxplot sem o eixo x
text(rep(3,5), c("*", "*", "**", "*", "***")) #adicionando os asteriscos
par(mgp=c(3,1.5,0)) #redefinindo a margem do eixo x do boxplot
axis(side= 1, at=1:6, gap.axis= -1, labels= c("Small\n","Medium\nEdge","Medium\nInterior","Large\nEdge",
                                              "Large\nInterior", "Control\n")) #adicionando a legenda do eixo x do boxplot
text(6.4,3,"b", cex= 1.5) #adicionando a letra 'b' no canto superior direito
dev.off()  #fechando o dispositivo png para salvar a imagem
